@@ -1,4 +1,4 @@
-{-# LANGUAGE MagicHash #-}
+{-# LANGUAGE CPP, MagicHash #-}
 
 -- |
 -- Module      : Data.Primitive.Internal.Compat
@@ -13,25 +13,12 @@
 
 module Data.Primitive.Internal.Compat (
     isTrue#
-  , mkNoRepType
   ) where
 
-#if MIN_VERSION_base(4,2,0)
-import Data.Data (mkNoRepType)
-#else
-import Data.Data (mkNorepType)
-#endif
-
 #if MIN_VERSION_base(4,7,0)
 import GHC.Exts (isTrue#)
 #endif
 
-
-
-#if !MIN_VERSION_base(4,2,0)
-mkNoRepType = mkNorepType
-#endif
-
 #if !MIN_VERSION_base(4,7,0)
 isTrue# :: Bool -> Bool
 isTrue# b = b
